pub fn inspect_windows_proxy(
runner: &dyn CommandRunner,
) -> Result<SystemProxySettings, String>Expand description
Inspect proxy settings from Windows Internet Settings registry keys.
On non-Windows platforms, returns an error.
pub fn inspect_windows_proxy(
runner: &dyn CommandRunner,
) -> Result<SystemProxySettings, String>Inspect proxy settings from Windows Internet Settings registry keys.
On non-Windows platforms, returns an error.