pub fn check_system_proxy_capability(
cap: SystemProxyCapability,
) -> SystemProxyStatusExpand description
Check the status of a specific system proxy capability by probing the system.
pub fn check_system_proxy_capability(
cap: SystemProxyCapability,
) -> SystemProxyStatusCheck the status of a specific system proxy capability by probing the system.